"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const commander_1 = tslib_1.__importDefault(require("commander"));
const utils_1 = require("./utils");
const compiler_1 = require("./lib/compiler");
const bundler_1 = require("./lib/bundler");
const serve_1 = require("./lib/serve");
exports.cli = (process) => {
    commander_1.default
        .option("-p", "--pwd <path>", "Current working directory")
        .option("-t", "--test", "Just a test flag");
    commander_1.default
        .command("build <path>")
        .option("-s, --source_config <path>", "The source of the project")
        .description("Run the compiler")
        .action((cmd, options) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const stasisConfig = yield utils_1.parseConfigFile(options.source_config);
        const compilationPromise = compiler_1.compiler(stasisConfig);
        const bundlePromise = bundler_1.bundle(stasisConfig);
        yield Promise.all([compilationPromise, bundlePromise]);
    }));
    commander_1.default
        .command("serve <path>")
        .option("-s, --source_config <path>", "The source of the project")
        .description("Start server")
        .action((cmd, options) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const stasisConfig = yield utils_1.parseConfigFile(options.source_config);
        const compilationPromise = compiler_1.compiler(stasisConfig);
        const bundlePromise = bundler_1.bundle(stasisConfig);
        yield Promise.all([compilationPromise, bundlePromise]);
        serve_1.startServer(stasisConfig, {});
    }));
    commander_1.default.parse(process.argv);
    return commander_1.default;
};
